# keyprotect
IBM Key Protect helps you provision encrypted keys for apps across IBM Cloud. As you manage the lifecycle of your keys, you can benefit from knowing that your keys are secured by cloud-based FIPS 140-2 Level 2 hardware security modules (HSMs) that protect against theft of information. You can use the Key Protect API to store, generate, and retrieve your key material. Keys within the service can protect any type of data in your symmetric key based encryption solution.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://cloud.ibm.com/docs/services/key-protect/](https://cloud.ibm.com/docs/services/key-protect/)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import keyprotect 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import keyprotect
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import keyprotect
from keyprotect.rest import ApiException
from pprint import pprint

configuration = keyprotect.Configuration()
# Configure Bearer authorization: bearerAuth
configuration.access_token = 'YOUR_BEARER_TOKEN'

# create an instance of the API class
api_instance = keyprotect.KeysApi(keyprotect.ApiClient(configuration))
bluemix_instance = 'bluemix_instance_example' # str | The IBM Cloud instance ID that identifies your Key Protect service instance.
id = 'id_example' # str | The root key that is used as the wrapping key. It must be a v4 UUID for an active key.
action = 'action_example' # str | The action to perform on the specified key.
key_action = {"plaintext":"<data_key>","aad":["<additional_data>","<additional_data>"]} # KeyAction | The request to perform a key wrap operation.
correlation_id = 'correlation_id_example' # str | The v4 UUID used to correlate and track transactions. (optional)
prefer = 'prefer_example' # str | Alters server behavior for POST or DELETE operations. A header with `return=minimal` causes the service to  return only the key identifier, or metadata. A header containing `return=representation` returns both the key  material and metadata in the response entity-body. If the key has been designated as a root key, the  system cannot return the key material.      **Note:** During POST operations, Key Protect may not immediately return the key material due to key generation time. To retrieve the key material, you can perform a subsequent `GET /keys/{id}` request. (optional)

try:
    # Invoke an action on a key
    api_response = api_instance.action_on_key(bluemix_instance, id, action, key_action, correlation_id=correlation_id, prefer=prefer)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling KeysApi->action_on_key: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://us-south.kms.cloud.ibm.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*KeysApi* | [**action_on_key**](docs/KeysApi.md#action_on_key) | **POST** /api/v2/keys/{id} | Invoke an action on a key
*KeysApi* | [**create_key**](docs/KeysApi.md#create_key) | **POST** /api/v2/keys | Create a new key
*KeysApi* | [**delete_key**](docs/KeysApi.md#delete_key) | **DELETE** /api/v2/keys/{id} | Delete a key by ID
*KeysApi* | [**get_key**](docs/KeysApi.md#get_key) | **GET** /api/v2/keys/{id} | Retrieve a key by ID
*KeysApi* | [**get_key_collection_metadata**](docs/KeysApi.md#get_key_collection_metadata) | **HEAD** /api/v2/keys | Retrieve the number of keys
*KeysApi* | [**get_keys**](docs/KeysApi.md#get_keys) | **GET** /api/v2/keys | Retrieve a list of keys
*PoliciesApi* | [**get_policy**](docs/PoliciesApi.md#get_policy) | **GET** /api/v2/keys/{id}/policies | Retrieve a list of policies
*PoliciesApi* | [**put_policy**](docs/PoliciesApi.md#put_policy) | **PUT** /api/v2/keys/{id}/policies | Replace an existing policy


## Documentation For Models

 - [CollectionMetadata](docs/CollectionMetadata.md)
 - [CreateKeyCollection](docs/CreateKeyCollection.md)
 - [CreatePolicyCollection](docs/CreatePolicyCollection.md)
 - [DeleteKeyCollection](docs/DeleteKeyCollection.md)
 - [Error](docs/Error.md)
 - [ErrorCollection](docs/ErrorCollection.md)
 - [GetKeyCollection](docs/GetKeyCollection.md)
 - [KeyAction](docs/KeyAction.md)
 - [KeyMetadata](docs/KeyMetadata.md)
 - [KeyMetadataAlgorithmMetadata](docs/KeyMetadataAlgorithmMetadata.md)
 - [ListKeyCollection](docs/ListKeyCollection.md)
 - [Policy](docs/Policy.md)
 - [PolicyRotation](docs/PolicyRotation.md)
 - [ReadKeyMaterial](docs/ReadKeyMaterial.md)
 - [WriteKeyMaterial](docs/WriteKeyMaterial.md)


## Documentation For Authorization


## bearerAuth

- **Type**: Bearer authentication


## Author




